@@ -11,7 +11,20 @@ from .instances.memory import DataPoint, DataPointProvider
 from .instances.text import TextInstance, TextInstanceProvider
 from .labels import LabelProvider
 from .labels.memory import MemoryLabelProvider
-from .machinelearning import SkLearnDataClassifier, SkLearnVectorClassifier
+from .machinelearning import SkLearnDataClassifier, SkLearnVectorClassifier, AbstractClassifier
+
+from .typehints import typevars
+
+import analysis
+import utils
+import exceptions
+import functions
+import ingest
+import instances
+import labels
+import machinelearning
+import pertubations
+
 
 __author__ = "Michiel Bron"
 __email__ = "m.p.bron@uu.nl"
@@ -25,7 +38,15 @@ __all__= [
     "TextEnvironment",
     "LabelProvider",
     "MemoryLabelProvider",
-    "SkLearnDataClassifier", "SkLearnVectorClassifier",
+    "SkLearnDataClassifier", "SkLearnVectorClassifier", "AbstractClassifier",
     "read_csv_dataset", "read_excel_dataset", "pandas_to_env", "pandas_to_env_with_id", 
-    "vectorize", "BaseVectorizer", "SklearnVectorizer", "TextInstanceVectorizer"
+    "vectorize", "BaseVectorizer", "SklearnVectorizer", "TextInstanceVectorizer", 
+    "analysis",
+    "utils",
+    "exceptions",
+    "functions",
+    "ingest",
+    "instances",
+    "pertubations",
+    "typevars"
 ]
